@@ -1,7 +1,7 @@
 import modin.pandas as mpd
 from modin.config import Engine
 
-from fuzzydata.clients.pandas import DataFrameArtifact, DataFrameOperation
+from fuzzydata.clients.pandas import DataFrameArtifact, DataFrameOperation, DataFrameWorkflow
 from fuzzydata.core.workflow import Workflow
 
 
@@ -20,21 +20,26 @@ class ModinArtifact(DataFrameArtifact):
         self.operation_class = DataFrameOperation
 
 
-class ModinWorkflow(Workflow):
+class ModinWorkflow(DataFrameWorkflow):
     def __init__(self, *args, **kwargs):
         self.modin_engine = kwargs.pop('modin_engine', 'dask')
         super(ModinWorkflow, self).__init__(*args, **kwargs)
         self.artifact_class = ModinArtifact
         self.operator_class = DataFrameOperation
 
+        self.wf_code_export = self.wf_code_export.replace("import pandas as pd", "import modin.pandas as pd")
+
         if self.modin_engine == 'dask':
             from dask.distributed import Client
             processes = kwargs.pop('processes', True)
             Client(processes=processes)
+            dask_code=f"\nfrom dask.distributed import Client\nClient(processes={processes})"
+            self.wf_code_export += dask_code
         else:
             import ray
             ray.init(ignore_reinit_error=True)
-
+            ray_code=f"\nimport ray\nray.init(ignore_reinit_error=True)"
+            self.wf_code_export += ray_code
         Engine.put(self.modin_engine)
 
     def initialize_new_artifact(self, label=None, filename=None, schema_map=None):
